function struct2=selectfields(struct1,names,~)  %  ~ noerror
% selectfields  Select fields from struct with optional noerror 
%  2017-07-09  Matlab2006+  Copyright (c) 2017, W J Whiten  BSD License
%
% s2=selectfields(s1,names,noerror)
%  struct1  Input struct or cell array of pairs
%  names    cell array of field names to be copied
%  noerror  If present no error message if name not a struct field
%
%  struct2  Struct giving selected fields from struct1
%
% Examples:
% t1=selectfields(struct('a',[1,2,3],'b',2,'c',3),{'a','c'})
% t1 = 
%   struct with fields:
% 
%     a: [1 2 3]
%     c: 3
%
% selectfields(struct('a',1,'c',3,'aa',11),{'a','b','c'},true)
% ans = 
%   struct with fields:
% 
%     a: 1
%     c: 3

if(nargin==3)
    noerror=true;
else
    noerror=false;
end

% empty new sruct
struct2=struct();

% copy field names given to new struct
for i=1:length(names)
    if(isfield(struct1,names{i}))
        struct2.(names{i})=struct1.(names{i});
    elseif(~noerror)
        error(['selectfields:  Field name  ''',names{i},  ...
            '''  not in struct']);
    end
end

return
end


% t1=selectfields(struct('a',[1,2,3],'b',2,'c',3),{'a','c'})
% t1 = 
%   struct with fields:
% 
%     a: [1 2 3]
%     c: 3



% selectfields([],'a','b','c')
% selectfields(struct('a',1,'c',3,'aa',11),'a','b','c')
% ans = 
%   struct with no fields.
% ans = 
%   struct with fields:
% 
%     a: 1
%     c: 3
